@@ -62,7 +62,7 @@ class HubzeroDatabaseConnection(object):
 
       config = ConfigParser.RawConfigParser()
       config.read('/etc/hubzero.conf')
-      section = config.get('default','site')
+      section = config.get('DEFAULT','site')
       docroot = config.get(section, 'DocumentRoot')
       file_read = open(docroot + '/configuration.php',"r")
       contents = file_read.read()
